@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
 require File.expand_path(File.join(File.dirname(__FILE__), 'utils'))
-miquire :lib, 'delayer', 'deferred'
 
+require 'delayer'
+require 'delayer/deferred'
 require 'set'
 require 'thread'
 require 'timeout'
@@ -34,7 +35,7 @@ class SerialThreadGroup
   alias new push
 
   # 処理中なら真
-  def self.busy?
+  def busy?
     @thread_pool.any?{ |t| :run == t.status.to_sym } end
 
   # 全てのserial threadの実行をキャンセルする。終了時の処理用
@@ -82,4 +83,3 @@ end
 # SerialThreadGroup のインスタンス。
 # 同時実行数は1固定
 SerialThread = SerialThreadGroup.new
-
